summaryrefslogtreecommitdiffstats
path: root/scd/app-openpgp.c
diff options
context:
space:
mode:
authorNIIBE Yutaka <gniibe@fsij.org>2017-04-28 03:06:33 +0200
committerNIIBE Yutaka <gniibe@fsij.org>2017-04-28 03:06:33 +0200
commit5c8fe5480964c282540c051b538e812851988422 (patch)
tree61da9fb34cfb67875bea2dc259741c0e9b8ca78f /scd/app-openpgp.c
parentg10: For signing, prefer available card key when no -u option. (diff)
downloadgnupg2-5c8fe5480964c282540c051b538e812851988422.tar.xz
gnupg2-5c8fe5480964c282540c051b538e812851988422.zip
Spelling fixes in docs and comments.
-- In addition, fix trailing spaces in tests/inittests. GnuPG-bug-id: 3121 Reported-by: ka7 (klemens) Signed-off-by: NIIBE Yutaka <gniibe@fsij.org>
Diffstat (limited to 'scd/app-openpgp.c')
-rw-r--r--scd/app-openpgp.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/scd/app-openpgp.c b/scd/app-openpgp.c
index 66b235d81..25f3dbef5 100644
--- a/scd/app-openpgp.c
+++ b/scd/app-openpgp.c
@@ -1588,7 +1588,7 @@ read_public_key (app_t app, ctrl_t ctrl, u32 created_at, int keyno,
}
/* Get the public key for KEYNO and store it as an S-expresion with
the APP handle. On error that field gets cleared. If we already
know about the public key we will just return. Note that this does
not mean a key is available; this is solely indicated by the
@@ -1596,7 +1596,7 @@ read_public_key (app_t app, ctrl_t ctrl, u32 created_at, int keyno,
Note that GnuPG 1.x does not need this and it would be too time
consuming to send it just for the fun of it. However, given that we
- use the same code in gpg 1.4, we can't use the gcry S-expresion
+ use the same code in gpg 1.4, we can't use the gcry S-expression
here but need to open encode it. */
#if GNUPG_MAJOR_VERSION > 1
static gpg_error_t
@@ -1588,7 +1588,7 @@ read_public_key (app_t app, ctrl_t ctrl, u32 created_at, int keyno,
}
-/* Get the public key for KEYNO and store it as an S-expresion with
+/* Get the public key for KEYNO and store it as an S-expression with
the APP handle. On error that field gets cleared. If we already
know about the public key we will just return. Note that this does